@@ -21,9 +21,13 @@ class Subscription(models.Model):
     user = models.ForeignKey(
         'auth.User',
         verbose_name=_('User'),
+        related_name='subscriptions',
     )
 
-    content_type = models.ForeignKey(ContentType)
+    content_type = models.ForeignKey(
+        ContentType,
+        related_name='subscribed',
+    )
     object_id = models.PositiveIntegerField()
     content_object = generic.GenericForeignKey('content_type', 'object_id')
 
